@@ -111,11 +111,6 @@ class Experimento:
             self.objeto_relevante_3 = puntos_importantes[2]
             self.objeto_relevante_4 = puntos_importantes[3]
 
-        self.cantidad_posiciones_cilindros_1 = None
-        self.cantidad_posiciones_cilindros_2 = None
-        self.cantidad_posiciones_cilindros_3 = None
-        self.cantidad_posiciones_cilindros_4 = None
-
         self.radios_cilindros = None
 
         self.distancia_a_objeto_promediado = None
@@ -191,6 +186,12 @@ class Experimento:
         self.matriz_recurrencia_region_cuadriculada = None
         self.matriz_cuadriculada = None
 
+        self.cantidad_posiciones_volumen_1 = None
+        self.cantidad_posiciones_volumen_2 = None
+        self.cantidad_posiciones_volumen_3 = None
+        self.cantidad_posiciones_volumen_4 = None
+        self.radios_volumenes = None
+
         print("Construcción de series de tiempo y de posición.")
 
         if self.posiciones_x.max() > dimension_caja[0]:
@@ -336,6 +337,28 @@ class Experimento:
         self.aceleracion_maxima = round(self.serie_aceleracion.max(), 3)
         print("Velocidad y aceleración del ratón calculdadas.")
 
+    def calcula_todos_histogramas(self):
+        self.calcula_histograma_velocidades()
+        self.calcula_histograma_objeto_1()
+        self.calcula_histograma_objeto_2()
+        self.calcula_histograma_objeto_3()
+        self.calcula_histograma_objeto_4()
+
+    def calcula_histograma_velocidades(self):
+        self.valores_histograma_velocidad, bins, bars = plt.hist(self.serie_velocidad)
+
+    def calcula_histograma_objeto_1(self):
+        self.valores_histograma_objeto_1, bins, bars = plt.hist(self.dist_objeto_1)
+
+    def calcula_histograma_objeto_2(self):
+        self.valores_histograma_objeto_2, bins, bars = plt.hist(self.dist_objeto_2)
+
+    def calcula_histograma_objeto_3(self):
+        self.valores_histograma_objeto_3, bins, bars = plt.hist(self.dist_objeto_3)
+
+    def calcula_histograma_objeto_4(self):
+        self.valores_histograma_objeto_4, bins, bars = plt.hist(self.dist_objeto_4)
+
     def calcula_velocidades_promediadas(self):
         longitud_serie_velocidad = len(self.serie_velocidad)
         longitud_serie_aceleracion = len(self.serie_aceleracion)
@@ -473,56 +496,58 @@ class Experimento:
                         self.matriz_recurrencia_objeto_4[i][j] = 1
                         self.matriz_recurrencia_combinada[i][j] = 4
 
-    def calcula_alturas_cilindros_objetos_relevantes(self, tamanio=24, divisiones=2):
+    def calcula_alturas_volumenes_circulares_objetos_relevantes(self, tamanio=24, divisiones=2, tipo="cilindros"):
         longitud_movimientos = len(self.posiciones_x)
         valor_min_divivido = int(tamanio / divisiones)
-        radios_cilindros = list(range(valor_min_divivido, tamanio + 1, valor_min_divivido))
-        cantidad_posiciones_cilindros_1 = list(np.zeros(len(radios_cilindros)))
-        cantidad_posiciones_cilindros_2 = list(np.zeros(len(radios_cilindros)))
-        cantidad_posiciones_cilindros_3 = list(np.zeros(len(radios_cilindros)))
-        cantidad_posiciones_cilindros_4 = list(np.zeros(len(radios_cilindros)))
+        radios_figuras = list(range(valor_min_divivido, tamanio + 1, valor_min_divivido))
+        cantidad_posiciones_volumen_1 = list(np.zeros(len(radios_figuras)))
+        cantidad_posiciones_volumen_2 = list(np.zeros(len(radios_figuras)))
+        cantidad_posiciones_volumen_3 = list(np.zeros(len(radios_figuras)))
+        cantidad_posiciones_volumen_4 = list(np.zeros(len(radios_figuras)))
+
         for i in range(0, longitud_movimientos):
             x_pos = self.posiciones_x[i]
             y_pos = self.posiciones_y[i]
             dist_1 = fa.calcula_distancia_entre_puntos(self.objeto_relevante_1[0], x_pos, self.objeto_relevante_1[1],
-                                                    y_pos)
+                                                       y_pos)
             dist_2 = fa.calcula_distancia_entre_puntos(self.objeto_relevante_2[0], x_pos, self.objeto_relevante_2[1],
-                                                    y_pos)
+                                                       y_pos)
             dist_3 = fa.calcula_distancia_entre_puntos(self.objeto_relevante_3[0], x_pos, self.objeto_relevante_3[1],
-                                                    y_pos)
+                                                       y_pos)
             dist_4 = fa.calcula_distancia_entre_puntos(self.objeto_relevante_4[0], x_pos, self.objeto_relevante_4[1],
-                                                    y_pos)
+                                                           y_pos)
             if dist_1 < tamanio:
-                cantidad_posiciones_cilindros_1 = fa.modificar_lista_para_cilindros(cantidad_posiciones_cilindros_1,
-                                                                                    radios_cilindros,
-                                                                                    dist_1)
+                cantidad_posiciones_volumen_1 = fa.modificar_lista_para_cilindros(cantidad_posiciones_volumen_1,
+                                                                                  radios_figuras,
+                                                                                  dist_1)
             if dist_2 < tamanio:
-                cantidad_posiciones_cilindros_2 = fa.modificar_lista_para_cilindros(cantidad_posiciones_cilindros_2,
-                                                                                    radios_cilindros,
-                                                                                    dist_2)
+                cantidad_posiciones_volumen_2 = fa.modificar_lista_para_cilindros(cantidad_posiciones_volumen_2,
+                                                                                  radios_figuras,
+                                                                                  dist_2)
             if dist_3 < tamanio:
-                cantidad_posiciones_cilindros_3 = fa.modificar_lista_para_cilindros(cantidad_posiciones_cilindros_3,
-                                                                                    radios_cilindros,
-                                                                                    dist_3)
+                cantidad_posiciones_volumen_3 = fa.modificar_lista_para_cilindros(cantidad_posiciones_volumen_3,
+                                                                                  radios_figuras,
+                                                                                  dist_3)
             if dist_4 < tamanio:
-                cantidad_posiciones_cilindros_4 = fa.modificar_lista_para_cilindros(cantidad_posiciones_cilindros_4,
-                                                                                    radios_cilindros,
-                                                                                    dist_4)
+                cantidad_posiciones_volumen_4 = fa.modificar_lista_para_cilindros(cantidad_posiciones_volumen_4,
+                                                                                  radios_figuras,
+                                                                                  dist_4)
 
-        print("Cantidad de posiciones para cilindro 1:")
-        print(cantidad_posiciones_cilindros_1)
-        print("Cantidad de posiciones para cilindro 2:")
-        print(cantidad_posiciones_cilindros_2)
-        print("Cantidad de posiciones para cilindro 3:")
-        print(cantidad_posiciones_cilindros_3)
-        print("Cantidad de posiciones para cilindro 4:")
-        print(cantidad_posiciones_cilindros_4)
 
-        self.cantidad_posiciones_cilindros_1 = cantidad_posiciones_cilindros_1
-        self.cantidad_posiciones_cilindros_2 = cantidad_posiciones_cilindros_2
-        self.cantidad_posiciones_cilindros_3 = cantidad_posiciones_cilindros_3
-        self.cantidad_posiciones_cilindros_4 = cantidad_posiciones_cilindros_4
-        self.radios_cilindros = radios_cilindros
+        print("Cantidad de posiciones para volumen 1:")
+        print(cantidad_posiciones_volumen_1)
+        print("Cantidad de posiciones para volumen 2:")
+        print(cantidad_posiciones_volumen_2)
+        print("Cantidad de posiciones para volumen 3:")
+        print(cantidad_posiciones_volumen_3)
+        print("Cantidad de posiciones para volumen 4:")
+        print(cantidad_posiciones_volumen_4)
+
+        self.cantidad_posiciones_volumen_1 = cantidad_posiciones_volumen_1
+        self.cantidad_posiciones_volumen_2 = cantidad_posiciones_volumen_2
+        self.cantidad_posiciones_volumen_3 = cantidad_posiciones_volumen_3
+        self.cantidad_posiciones_volumen_4 = cantidad_posiciones_volumen_4
+        self.radios_volumenes = radios_figuras
 
     def obtener_indice_regiones_objeto(self):
         lista_objetos_relevantes = [self.objeto_relevante_1,
@@ -716,33 +741,6 @@ class Experimento:
                             sucesion_nueva
                         self.lista_indices_subsucesiones_parecidas[i].append(j)
 
-    """
-    def calcula_distancias_entre_subsucesiones(self, tamanio, epsilon):
-        lista_con_subsucesiones = self.crea_sucesiones_a_evaluar(tamanio)
-        for i in range(len(lista_con_subsucesiones)):
-            dataframe_subsucesiones_parecidas = pd.DataFrame()
-            indices = [i]
-            sucesion_1 = lista_con_subsucesiones[i]
-            print(sucesion_1)
-            dataframe_subsucesiones_parecidas[0] = sucesion_1
-            print("Indice:", i)
-            print(dataframe_subsucesiones_parecidas)
-            for j in range(i+(tamanio-1), len(lista_con_subsucesiones)):
-                sucesion_2 = lista_con_subsucesiones[j]
-                se_encontro_epsilon = self.distancia_entre_sucesiones(sucesion_1, sucesion_2, epsilon)
-                if se_encontro_epsilon:
-                    dataframe_subsucesiones_parecidas[len(dataframe_subsucesiones_parecidas.columns)+1] = sucesion_2
-                    print(dataframe_subsucesiones_parecidas)
-                    indices.append(j)
-                    print("Indice:", j)
-            print("Se termina de buscar subsucesiones.")
-            if len(dataframe_subsucesiones_parecidas.columns) > 1:
-                break
-        print("Indices de subsucesiones: ", indices)
-        print("Dataframe resultante")
-        print(dataframe_subsucesiones_parecidas)
-    """
-
     def calcula_distancias_entre_sucesiones(self, brinco, epsilon=1):
         print("---------------------------------------------------------------")
         copia_sucesion_original = self.arreglo_region_cuadriculada.copy()
@@ -850,9 +848,23 @@ class Experimento:
         data = pd.DataFrame(self.matriz_cuadriculada, columns=None, index=None)
         data.to_csv(nombre, header=None, index=None)
 
+    def exporta_regiones_circulares(self, nombre):
+        data = {'1': ['Objeto_1',
+                      'Objeto_2',
+                      'Objeto_3',
+                      'Objeto_4',],
+                '2': [self.cantidad_posiciones_volumen_1,
+                      self.cantidad_posiciones_volumen_2,
+                      self.cantidad_posiciones_volumen_3,
+                      self.cantidad_posiciones_volumen_4,
+                      ]}
+        data = pd.DataFrame(data)
+        data.to_csv(nombre, header=None, index=None)
+
     def grafica(self, grafica, lim_inf_x=None, lim_sup_x=None, lim_inf_y=None, lim_sup_y=None,
                 tamanio_vectores=100, brinco_temporal=int(1), consencuencia_elegida=None,
-                tamanio_cilindros=24, div_cilindros=2, arreglo_grafica_distancias=[True, True, True, True],
+                tamanio_volumenes=24, div_volumenes=2, tipo_grafica_volumen="cilindros",
+                arreglo_grafica_distancias=[True, True, True, True],
                 rotacion_grafica_3d=220):
 
         print("-----------------------------------------------------------")
@@ -1169,10 +1181,11 @@ class Experimento:
         #        plt.imshow(np.flipud(self.matriz_cuadriculada)))
 
         elif grafica == 'cilindros_objetos_importantes':
-            print("Entro a cilindros_objetos_importantes")
+            print("Entro a volumenes_objetos_importantes")
 
-            self.calcula_alturas_cilindros_objetos_relevantes(tamanio=tamanio_cilindros,
-                                                              divisiones=div_cilindros)
+            self.calcula_alturas_volumenes_circulares_objetos_relevantes(tamanio=tamanio_volumenes,
+                                                                         divisiones=div_volumenes,
+                                                                         tipo=tipo_grafica_volumen)
             rot_grafica_3d = rotacion_grafica_3d
 
             if getattr(sys, 'frozen', False):
@@ -1181,28 +1194,31 @@ class Experimento:
             ax = fig.add_subplot(111, projection='3d')
             ax.view_init(azim=rot_grafica_3d % 360, elev=0)
 
-            for i in range(0, len(self.cantidad_posiciones_cilindros_1)):
-                fa.pintar_cilindro(self.objeto_relevante_1[0],
-                                   self.objeto_relevante_1[1],
-                                   self.radios_cilindros[i],
-                                   self.cantidad_posiciones_cilindros_1[i],
-                                   ax)
-                fa.pintar_cilindro(self.objeto_relevante_2[0],
-                                   self.objeto_relevante_2[1],
-                                   self.radios_cilindros[i],
-                                   self.cantidad_posiciones_cilindros_2[i],
-                                   ax)
-                fa.pintar_cilindro(self.objeto_relevante_3[0],
-                                   self.objeto_relevante_3[1],
-                                   self.radios_cilindros[i],
-                                   self.cantidad_posiciones_cilindros_3[i],
-                                   ax)
-                fa.pintar_cilindro(self.objeto_relevante_4[0],
-                                   self.objeto_relevante_4[1],
-                                   self.radios_cilindros[i],
-                                   self.cantidad_posiciones_cilindros_4[i],
-                                   ax)
-
+            for i in range(0, len(self.cantidad_posiciones_volumen_1)):
+                if arreglo_grafica_distancias[0] is True:
+                    fa.pintar_cilindro(self.objeto_relevante_1[0],
+                                       self.objeto_relevante_1[1],
+                                       self.radios_cilindros[i],
+                                       self.cantidad_posiciones_volumen_1[i],
+                                       ax)
+                if arreglo_grafica_distancias[1] is True:
+                    fa.pintar_cilindro(self.objeto_relevante_2[0],
+                                       self.objeto_relevante_2[1],
+                                       self.radios_cilindros[i],
+                                       self.cantidad_posiciones_volumen_2[i],
+                                       ax)
+                if arreglo_grafica_distancias[2] is True:
+                    fa.pintar_cilindro(self.objeto_relevante_3[0],
+                                       self.objeto_relevante_3[1],
+                                       self.radios_cilindros[i],
+                                       self.cantidad_posiciones_volumen_3[i],
+                                       ax)
+                if arreglo_grafica_distancias[3] is True:
+                    fa.pintar_cilindro(self.objeto_relevante_4[0],
+                                       self.objeto_relevante_4[1],
+                                       self.radios_cilindros[i],
+                                       self.cantidad_posiciones_volumen_4[i],
+                                       ax)
             ax.set_xlim(0, 100)
             ax.set_ylim(0, 100)
             ax.set_zlim(0, len(self.posiciones_x))
